Scripts can also move across much larger granularities and time frames. For example, Håklev (2016) describes a script which begins by thousands of students (in-service teachers) contributing individual educational resources that they find useful. Students are then presented with relevant resources to their own teaching (based on semantic tags), and tag, vote and add comments. The curated and annotated list of resources feed into the small (3-6 person) groups which work on developing a lesson plan using technology. Their work in progress is cycled back to the community for constructive peer-review on a weekly basis. Thus we see overlapping scripts that last over several weeks, and which distributes input from thousands of students, to small teams, and back to larger “communities of interest”.

## Repair/orchestration
All of the individual activities, and the graph as a whole, has a standardised interface for live-streaming learning traces (log data) from learners, and a well-defined API for the teacher to interface with the execution (re-ordering groups, modifying the configuration or order of activities, etc). This can allow an instructional team to monitor the progress of thousands of students through innovative visualisations and alerting systems, and interfere where groups are not working well, or the community is not moving forwards as planned. Given this standardised interface, it would also be feasible to construct bots that use machine learning to “act on the teacher’s behalf” (perhaps even trained on a history of teacher actions), automatically monitoring group and individual student progress, and intervening when necessary. 

# Ecosystem of activities and operators
The online education space has a long history of plugins, widgets and protocols for integrating external learning activities into Learning Management Systems, and now MOOCs. However, several of our requirements fail to be met by existing standards: the ability to have an artefact generated in one activity used as an input in another activity, the access to a live stream of learning analytics data, and the ability for a teacher to “orchestrate”/intervene in an ongoing activity.

We have defined an API protocol to enable rich integration with highly modular activities. Activities are currently distributed as separate NPM Javascript packages, but in the future, we will also allow for activities which run on separate servers. Activities provide their own metadata, configuration function (a video player requires a URL, a quiz requires questions and alternatives), and a “runner”, which receives the configuration data, the input data from any previous activities, and a social structure.
Operators are located on the edge between two nodes, and receive the student products from the source node, and either transforms the product, or generate new social structures based on the student products. Operators are also separate NPM Javascript packages (and will be able to run on remote servers as APIs), providing a configuration function, and a “runner”, which receives it’s own configuration, as well the data to process, returning the output data or social structure. 

<< need diagram of activities/operators etc? >>

# Integration in MOOC platforms
Currently, the Orchestration Engine is being developed as a stand-alone tool, however there are several possible ways in which it might be integrated within traditional MOOC platforms. One possibility could be to offer a several synchronous sessions within a MOOC. Students could be asked to log on at a certain time and date, and visit a specific activity in EdX or Coursera, or any other platform supporting the Learning Tools Integration (LTI) API. 

This activity would function as a “window” to the Orchestration Engine, and within this window, an entire learning scenario could play out - for example a jigsaw discussion as mentioned in example above. While the script was running, the instructional staff would be monitoring the life learning analytics, and have the ability to intervene to repair or improve the script, etc.

However, we could also imagine that each separate activity in an Orchestration Graph could be given a unique LTI URL. A course designer in for example EdX who wanted to implement something similar to the macro script described in Håklev, 2016, could add a “Individual survey” activity in week 1 of the MOOC, after videos and quizzes. In the graph, this activity would be connected to an operator that generates groups based on the responses, and further to a group activity. The designer could then insert the group activity as a separate LTI component in week 2 of the EdX course, and the engine would take care of all the data flow and social structure behind the scenes.

# Future possibilities
Our work on the educational modelling language Orchestration Graphs, and the technical infrastructure/architecture for editing and running these graphs form part of a larger research program to empirically investigate and improve our understanding of large-scale collaborative learning scripts. Traditional learning analytics of MOOCs has generated large amounts of data points, but the analysis has rarely taken into account the instructional design or the pedagogical role of each activity. If we begin with a computer legible description of the pedagogical design, and can automatically map rich learning analytics (both general, and activity-specific) onto the graphs, we can begin to develop models of student learning in the forms of transition matrices (predicting the success of a student on an activity from his observed behaviour, his performance on the previous activity and the performance of other students on the current activity)(how predictive is success in activity a1 for success in activity a2, for which kind of learner). 

# Current status and conclusion
We currently have a prototype system ready, which allows users to edit scripts, adding and configuring activities and operators. We have a set of activities and operators, which are all completely isolated code-bases connected to the Engine through the public API, and we are able to run scripts generated by the editor, with learning analytics and teacher orchestration capabilities.

We are in the process of refining the design of the API, and expanding the collection of activities and operators, as well as rebuilding the architecture to be more scaleable (distributed across multiple servers). We plan a number of smaller experiments in the spring of 20176 aimed at testing UI/UX with instructional designers/teachers, and running scripts with actual students. The platform will then become an integral part of an EdX MOOC in fall 2017, when students will not only participate in scripts designed by the instructor, but will also get the opportunity to themselves design and run scripts as part of the learning process. 

# Sources

